@@ -1172,7 +1172,9 @@ class LRSchedulerCallback(CallbackInterface, metaclass=SuperclassDocstring):
 @dataclass
 class ProgressBarCallback(CallbackInterface, metaclass=SuperclassDocstring):
     r"""
-    Barre de progression TQDM sur les époques et les évaluations.
+    Barre de progression TQDM sur les époques et les évaluations. Dans le
+    cadre multi-node affiche la bare de progression sur chacun des serveurs
+    noeuds.
 
     mininterval: float (=0.5)
         Temps en seconde entre les intervalles de raffraichissement de la 
@@ -1191,7 +1193,10 @@ class ProgressBarCallback(CallbackInterface, metaclass=SuperclassDocstring):
 
     def __post_init__(self):
         from dstk.pytorch._utils_distrib import is_main_process
-        self.is_main = is_main_process
+        if 'LOCAL_RANK' in os.environ:
+            self.is_main = lambda: os.environ['LOCAL_RANK'] == 0
+        else:
+            self.is_main = is_main_process
 
     def begin_epoch(
         self,
