@@ -403,7 +403,7 @@ class RandomizedSearchOnline:
             else:
                 (test_score_dicts, test_sample_counts, fit_time,
                  score_time) = zip(*out)
-        else:
+        elif sklearn_version < '1.0.1':
             out_ = l2d(out)
             fit_failed = out_['fit_failed']
             test_score_dicts = out_['test_scores']
@@ -412,6 +412,15 @@ class RandomizedSearchOnline:
             score_time = out_['score_time']
             if self.return_train_score:
                 train_score_dicts = out_['train_scores']
+        else:
+            out_ = l2d(out)
+            fit_failed = out_['fit_error']
+            test_score_dicts = out_['test_scores']
+            # test_sample_counts = out_['n_test_samples']
+            fit_time = out_['fit_time']
+            score_time = out_['score_time']
+            if self.return_train_score:
+                train_score_dicts = out_['train_scores']
 
         test_scores = {
             key: np.asarray(
@@ -437,7 +446,7 @@ class RandomizedSearchOnline:
                 if monte_carlo:
                     for mc_i in range(self.monte_carlo):
                         results[f"mc{mc_i}_{key_name}"] = array[:, mc_i]
-                if key_name != 'fit_failed':
+                if not key_name in ('fit_failed', 'fit_error'):
                     array_means = np.average(array, axis=1)
                     results[f"mean_{key_name}"] = array_means
                     array_stds = np.std(array, axis=1)
@@ -495,16 +504,16 @@ class RandomizedSearchOnline:
 
         for scorer_name in scorers.keys():
             _store(
-                key_name = f"test_{scorer_name}",
-                array = test_scores[scorer_name],
-                monte_carlo = True,
-                rank = True
+                key_name=f"test_{scorer_name}",
+                array=test_scores[scorer_name],
+                monte_carlo=True,
+                rank=True
             )
             if self.return_train_score:
                 _store(
-                    key_name = f"train_{scorer_name}",
-                    array = train_scores[scorer_name],
-                    monte_carlo = True
+                    key_name=f"train_{scorer_name}",
+                    array=train_scores[scorer_name],
+                    monte_carlo=True
                 )
 
         return results
